@@ -12,7 +12,7 @@ use Capture::Tiny ();
 use File::Path ();
 
 # ABSTRACT: Build shared libraries for use with FFI
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.03_01'; # TRIAL VERSION
 
 
 sub _native_name
@@ -40,6 +40,7 @@ sub new
   my $file      = $self->{file}      = $args{file}      || FFI::Build::File::Library->new([$args{dir} || '.', $self->_native_name($name)], platform => $self->platform);
   my $buildname = $self->{buildname} = $args{buildname} || '_build';
   my $verbose   = $self->{verbose}   = $args{verbose}   || 0;
+  my $export    = $self->{export}    = $args{export}    || [];
 
   if(defined $args{cflags})
   {
@@ -81,6 +82,7 @@ sub new
 
 
 sub buildname { shift->{buildname} }
+sub export    { shift->{export}    }
 sub file      { shift->{file}      }
 sub platform  { shift->{platform}  }
 sub verbose   { shift->{verbose}   }
@@ -234,6 +236,7 @@ sub build
     $self->platform->ldflags,
     (map { "$_" } @objects),
     $self->libs,
+    $self->platform->flag_export(@{ $self->export }),
     $self->platform->flag_library_output($self->file->path),
   );
 
@@ -289,7 +292,7 @@ FFI::Build - Build shared libraries for use with FFI
 
 =head1 VERSION
 
-version 1.00
+version 1.03_01
 
 =head1 SYNOPSIS
 
@@ -312,9 +315,6 @@ version 1.00
 
 =head1 DESCRIPTION
 
-B<WARNING>: Alpha quality software, expect a somewhat unstable API until it stabilizes.  Documentation
-may be missing or inaccurate.
-
 Using libffi based L<FFI::Platypus> is a great alternative to XS for writing library bindings for Perl.
 Sometimes, however, you need to bundle a little C code with your FFI module, but this has never been
 that easy to use.  L<Module::Build::FFI> was an early attempt to address this use case, but it uses
@@ -367,6 +367,10 @@ Extra compiler flags to use.  Things like C<-I/foo/include> or C<-DFOO=1>.
 
 The directory where the library will be written.  This is C<.> by default.
 
+=item export
+
+Functions that should be exported (Windows + Visual C++ only)
+
 =item file
 
 An instance of L<FFI::Build::File::Library> to which the library will be written.  Normally not needed.
@@ -423,6 +427,12 @@ Returns the build name.  This is used in computing a directory to save intermedi
 if you specify a file like C<ffi/foo.c>, then the object file will be stored in C<ffi/_build/foo.o> by default.
 C<_build> in this example (the default) is the build name.
 
+=head2 export
+
+ my $exports = $build->export;
+
+Returns a array reference of the exported functions (Windows + Visual C++ only)
+
 =head2 file
 
  my $file = $build->file;
