@@ -8,7 +8,7 @@ use FFI::Platypus::Function;
 use FFI::Platypus::Type;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.03_01'; # TRIAL VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -525,7 +525,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 1.00
+version 1.03_01
 
 =head1 SYNOPSIS
 
@@ -670,7 +670,7 @@ Enable the next generation type parser which allows pass-by-value records
 and type decoration on basic types.  Using API level 1 prior to Platypus
 version 1.00 will trigger a (noisy) warning.
 
-All new code should be written with C<api => 1>!  The Platypus documentation
+All new code should be written with this set to 1!  The Platypus documentation
 assumes this api level is set.
 
 =back
@@ -1228,7 +1228,7 @@ L<FFI::Platypus::Memory> module.
  
  use FFI::Platypus::Record;
  
- record_layout(qw(
+ record_layout_1(qw(
      int    tm_sec
      int    tm_min
      int    tm_hour
@@ -1870,10 +1870,10 @@ a tool (L<Convert::Binary::C> can do this) that can extract the constants for yo
 See also the "Integer constants" example in L<FFI::Platypus::Type>.
 
 You can also use the new Platypus bundle interface to define Perl constants
-from C space.  This is more reliable, but does require a compiler.  It is
-recommended mainly for writing bindings against libraries that have constants
-that can vary widely from platform to platform.  See L<FFI::Platypus::Constant>
-for details.
+from C space.  This is more reliable, but does require a compiler at install
+time.  It is recommended mainly for writing bindings against libraries that
+have constants that can vary widely from platform to platform.  See
+L<FFI::Platypus::Constant> for details.
 
 =head2 What about enums?
 
