@@ -8,7 +8,7 @@ use Text::ParseWords ();
 use FFI::Build::Platform;
 
 # ABSTRACT: Probe runner builder for FFI
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.03_01'; # TRIAL VERSION
 
 
 sub new
@@ -173,20 +173,55 @@ sub build
   my($self) = @_;
   $self->extract;
 
+  # this should really be done in `new` but the build
+  # scripts for FFI-Platypus edit the ldfalgs from there
+  # so.  Also this may actually belong in FFI::Build::Platform
+  # which would resolve the problem.
+  if($^O eq 'MSWin32' && $Config{ccname} eq 'cl')
+  {
+    $self->{ldflags} = [
+      grep !/^-nodefaultlib$/i,
+      @{ $self->{ldflags} }
+    ];
+  }
+
   my $cfn = $self->file('src', 'dlrun.c');
   my $ofn = $self->file('src', "dlrun$Config{obj_ext}");
   my $xfn = $self->exe;
 
   # compile
   print "CC src/dlrun.c\n" unless $VERBOSE;
-  $self->run(compile => $self->cc, $self->ccflags, $self->optimize, '-c', '-o' => $ofn, $cfn);
+  $self->run(
+    compile =>
+      $self->cc,
+      $self->ccflags,
+      $self->optimize,
+      '-c',
+      $self->{platform}->flag_object_output($ofn),
+      $cfn,
+  );
 
   # link
   print "LD src/dlrun$Config{obj_ext}\n" unless $VERBOSE;
   $self->run_list(link =>
-    map { [$self->ld, $self->ldflags, '-o' => $xfn, $ofn, @$_ ] } @{ $self->libs },
+    map { [
+      $self->ld,
+      $self->ldflags,
+      $self->{platform}->flag_exe_output($xfn),
+      $ofn,
+      @$_
+    ] } @{ $self->libs },
   );
 
+  ## FIXME
+  if($^O eq 'MSWin32' && $Config{ccname} eq 'cl')
+  {
+    if(-f 'dlrun.exe' && ! -f $xfn)
+    {
+      rename 'dlrun.exe', $xfn;
+    }
+  }
+
   # verify
   print "VV bin/dlrun$Config{exe_ext}\n" unless $VERBOSE;
   my $out = $self->run(verify => $xfn, 'verify', 'self');
@@ -215,7 +250,7 @@ FFI::Probe::Runner::Builder - Probe runner builder for FFI
 
 =head1 VERSION
 
-version 1.00
+version 1.03_01
 
 =head1 SYNOPSIS
 
